@@ -2,7 +2,7 @@ package Catalyst::Controller::REST;
 use strict;
 use warnings;
 
-our $VERSION = '0.78';
+our $VERSION = '0.79';
 $VERSION = eval $VERSION;
 
 =head1 NAME
@@ -12,8 +12,10 @@ Catalyst::Controller::REST - A RESTful controller
 =head1 SYNOPSIS
 
     package Foo::Controller::Bar;
-
-    use base 'Catalyst::Controller::REST';
+    use Moose;
+    use namespace::autoclean;
+    
+    BEGIN { extends 'Catalyst::Controller::REST' }
 
     sub thing : Local : ActionClass('REST') { }
 
@@ -34,7 +36,7 @@ Catalyst::Controller::REST - A RESTful controller
 
     # Answer PUT requests to "thing"
     sub thing_PUT {
-      .. some action ..
+      ... some action ...
     }
 
 =head1 DESCRIPTION
@@ -76,7 +78,12 @@ If we do not have (or cannot run) a serializer for a given content-type, a 415
 
 To make your Controller RESTful, simply have it
 
-  use base 'Catalyst::Controller::REST';
+  BEGIN { extends 'Catalyst::Controller::REST' }
+
+=head1 CONFIGURATION
+
+See L<Catalyst::Action::Serialize/CONFIGURATION>. Note that the C<serialize>
+key has been deprecated.
 
 =head1 SERIALIZATION
 
@@ -85,7 +92,7 @@ responses, and deserialize any POST, PUT or OPTIONS requests. It evaluates
 which serializer to use by mapping a content-type to a Serialization module.
 We select the content-type based on:
 
-=over 2
+=over
 
 =item B<The Content-Type Header>
 
@@ -108,56 +115,56 @@ A given serialization mechanism is only available if you have the underlying
 modules installed.  For example, you can't use XML::Simple if it's not already
 installed.
 
-In addition, each serializer has it's quirks in terms of what sorts of data
+In addition, each serializer has its quirks in terms of what sorts of data
 structures it will properly handle.  L<Catalyst::Controller::REST> makes
 no attempt to save you from yourself in this regard. :)
 
 =over 2
 
-=item C<text/x-yaml> => C<YAML::Syck>
+=item * C<text/x-yaml> => C<YAML::Syck>
 
 Returns YAML generated by L<YAML::Syck>.
 
-=item C<text/html> => C<YAML::HTML>
+=item * C<text/html> => C<YAML::HTML>
 
 This uses L<YAML::Syck> and L<URI::Find> to generate YAML with all URLs turned
 to hyperlinks.  Only useable for Serialization.
 
-=item C<application/json> => C<JSON>
+=item * C<application/json> => C<JSON>
 
 Uses L<JSON> to generate JSON output.  It is strongly advised to also have
 L<JSON::XS> installed.  The C<text/x-json> content type is supported but is
 deprecated and you will receive warnings in your log.
 
-=item C<text/x-data-dumper> => C<Data::Serializer>
+=item * C<text/x-data-dumper> => C<Data::Serializer>
 
 Uses the L<Data::Serializer> module to generate L<Data::Dumper> output.
 
-=item C<text/x-data-denter> => C<Data::Serializer>
+=item * C<text/x-data-denter> => C<Data::Serializer>
 
 Uses the L<Data::Serializer> module to generate L<Data::Denter> output.
 
-=item C<text/x-data-taxi> => C<Data::Serializer>
+=item * C<text/x-data-taxi> => C<Data::Serializer>
 
 Uses the L<Data::Serializer> module to generate L<Data::Taxi> output.
 
-=item C<application/x-storable> => C<Data::Serializer>
+=item * C<application/x-storable> => C<Data::Serializer>
 
 Uses the L<Data::Serializer> module to generate L<Storable> output.
 
-=item C<application/x-freezethaw> => C<Data::Serializer>
+=item * C<application/x-freezethaw> => C<Data::Serializer>
 
 Uses the L<Data::Serializer> module to generate L<FreezeThaw> output.
 
-=item C<text/x-config-general> => C<Data::Serializer>
+=item * C<text/x-config-general> => C<Data::Serializer>
 
 Uses the L<Data::Serializer> module to generate L<Config::General> output.
 
-=item C<text/x-php-serialization> => C<Data::Serializer>
+=item * C<text/x-php-serialization> => C<Data::Serializer>
 
 Uses the L<Data::Serializer> module to generate L<PHP::Serialization> output.
 
-=item C<text/xml> => C<XML::Simple>
+=item * C<text/xml> => C<XML::Simple>
 
 Uses L<XML::Simple> to generate XML output.  This is probably not suitable
 for any real heavy XML work. Due to L<XML::Simple>s requirement that the data
@@ -165,37 +172,63 @@ you serialize be a HASHREF, we transform outgoing data to be in the form of:
 
   { data => $yourdata }
 
-=item L<View>
+=item * L<View>
 
 Uses a regular Catalyst view.  For example, if you wanted to have your
-C<text/html> and C<text/xml> views rendered by TT:
+C<text/html> and C<text/xml> views rendered by TT, set:
 
-  'text/html' => [ 'View', 'TT' ],
-  'text/xml'  => [ 'View', 'XML' ],
+  __PACKAGE__->config(
+      map => {
+          'text/html' => [ 'View', 'TT' ],
+          'text/xml'  => [ 'View', 'XML' ],
+      }
+  );
 
-Will do the trick nicely.
+Your views should have a C<process> method like this:
+
+  sub process {
+      my ( $self, $c, $stash_key ) = @_;
+
+      my $output;
+      eval {
+          $output = $self->serialize( $c->stash->{$stash_key} );
+      };
+      return $@ if $@;
+
+      $c->response->body( $output );
+      return 1;  # important
+  }
+  
+  sub serialize {
+      my ( $self, $data ) = @_;
+
+      my $serialized = ... process $data here ...
+
+      return $serialized;
+  }
 
 =back
 
-By default, L<Catalyst::Controller::REST> will return a C<415 Unsupported Media Type>
-response if an attempt to use an unsupported content-type is made.  You
-can ensure that something is always returned by setting the C<default>
-config option:
+By default, L<Catalyst::Controller::REST> will return a 
+C<415 Unsupported Media Type> response if an attempt to use an unsupported
+content-type is made.  You can ensure that something is always returned by
+setting the C<default> config option:
 
-  __PACKAGE__->config->{'default'} = 'text/x-yaml';
+  __PACKAGE__->config(default => 'text/x-yaml');
 
-Would make it always fall back to the serializer plugin defined for text/x-yaml.
-
-Implementing new Serialization formats is easy!  Contributions
-are most welcome!  See L<Catalyst::Action::Serialize> and
-L<Catalyst::Action::Deserialize> for more information.
+would make it always fall back to the serializer plugin defined for
+C<text/x-yaml>.
 
 =head1 CUSTOM SERIALIZERS
 
-If you would like to implement a custom serializer, you should create two new
-modules in the L<Catalyst::Action::Serialize> and
-L<Catalyst::Action::Deserialize> namespace.  Then assign your new class
-to the content-type's you want, and you're done.
+Implementing new Serialization formats is easy!  Contributions
+are most welcome!  If you would like to implement a custom serializer, 
+you should create two new modules in the L<Catalyst::Action::Serialize>
+and L<Catalyst::Action::Deserialize> namespace.  Then assign your new
+class to the content-type's you want, and you're done.
+
+See L<Catalyst::Action::Serialize> and L<Catalyst::Action::Deserialize> 
+for more information.
 
 =head1 STATUS HELPERS
 
@@ -208,7 +241,7 @@ refer to it at: L<http://www.w3.org/Protocols/rfc2616/rfc2616.txt>.
 These routines are all implemented as regular subroutines, and as
 such require you pass the current context ($c) as the first argument.
 
-=over 4
+=over
 
 =cut
 
@@ -228,9 +261,9 @@ __PACKAGE__->config(
         'text/x-data-dumper' => [ 'Data::Serializer', 'Data::Dumper' ],
         'text/x-data-denter' => [ 'Data::Serializer', 'Data::Denter' ],
         'text/x-data-taxi'   => [ 'Data::Serializer', 'Data::Taxi'   ],
-        'application/x-storable'    => [ 'Data::Serializer', 'Storable'     ],
-        'application/x-freezethaw'  => [ 'Data::Serializer', 'FreezeThaw'   ],
-        'text/x-config-general' => [ 'Data::Serializer', 'Config::General' ],
+        'application/x-storable'   => [ 'Data::Serializer', 'Storable' ],
+        'application/x-freezethaw' => [ 'Data::Serializer', 'FreezeThaw' ],
+        'text/x-config-general'    => [ 'Data::Serializer', 'Config::General' ],
         'text/x-php-serialization' => [ 'Data::Serializer', 'PHP::Serialization' ],
     },
 );
@@ -452,26 +485,21 @@ L<Catalyst::Action::Serialize> and L<Catalyst::Action::Deserialize>.  It should
 This class provides a default configuration for Serialization.  It is currently:
 
   __PACKAGE__->config(
-      serialize => {
-         'stash_key' => 'rest',
-         'map'       => {
-            'text/html'          => 'YAML::HTML',
-            'text/xml'           => 'XML::Simple',
-            'text/x-yaml'        => 'YAML',
-            'application/json'   => 'JSON',
-            'text/x-json'        => 'JSON',
-            'text/x-data-dumper' => [ 'Data::Serializer', 'Data::Dumper' ],
-            'text/x-data-denter' => [ 'Data::Serializer', 'Data::Denter' ],
-            'text/x-data-taxi'   => [ 'Data::Serializer', 'Data::Taxi'   ],
-            'application/x-storable'    => [ 'Data::Serializer', 'Storable'
-],
-            'application/x-freezethaw'  => [ 'Data::Serializer', 'FreezeThaw'
-],
-            'text/x-config-general' => [ 'Data::Serializer', 'Config::General' ]
-,
-            'text/x-php-serialization' => [ 'Data::Serializer', 'PHP::Serialization' ],
-          },
-      }
+      'stash_key' => 'rest',
+      'map'       => {
+         'text/html'          => 'YAML::HTML',
+         'text/xml'           => 'XML::Simple',
+         'text/x-yaml'        => 'YAML',
+         'application/json'   => 'JSON',
+         'text/x-json'        => 'JSON',
+         'text/x-data-dumper' => [ 'Data::Serializer', 'Data::Dumper' ],
+         'text/x-data-denter' => [ 'Data::Serializer', 'Data::Denter' ],
+         'text/x-data-taxi'   => [ 'Data::Serializer', 'Data::Taxi'   ],
+         'application/x-storable'   => [ 'Data::Serializer', 'Storable' ],
+         'application/x-freezethaw' => [ 'Data::Serializer', 'FreezeThaw' ],
+         'text/x-config-general'    => [ 'Data::Serializer', 'Config::General' ],
+         'text/x-php-serialization' => [ 'Data::Serializer', 'PHP::Serialization' ],
+      },
   );
 
 You can read the full set of options for this configuration block in
@@ -522,15 +550,9 @@ Wikipedia! http://en.wikipedia.org/wiki/Representational_State_Transfer
 
 The REST Wiki: http://rest.blueoxen.net/cgi-bin/wiki.pl?FrontPage
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Adam Jacob <adam@stalecoffee.org>, with lots of help from mst and jrockway
-
-Marchex, Inc. paid me while I developed this module.  (http://www.marchex.com)
-
-=head1 MAINTAINER
-
-J. Shirley <jshirley@cpan.org>
+See L<Catalyst::Action::REST> for authors.
 
 =head1 LICENSE
 
